# The baseline for module testing used by Puppet Labs is that each manifest
# should have a corresponding test manifest that declares that class or defined
# type.
#
# Tests are then run by using puppet apply --noop (to check for compilation
# errors and view a log of events) or by fully applying the test in a virtual
# environment (to compare the resulting system state to the desired state).
#
# Learn more about module testing here:
# http://docs.puppetlabs.com/guides/tests_smoke.html
#
include duplicity::install

$jira_home                = '/var/atlassian/application-data/jira'
$jira_install_dir         = '/opt/atlassian/jira'
$backup_server            = "192.168.0.251"
$backup_user              = "backup_user"
$backup_transfer_type     = "rsync"
$backup_base              = "/backup"
$backup_agent_node        = $::hostname
$full_backup_interval     = '2W'
$last_full_backup_to_keep = '24'
$last_increment_to_keep   = '110'
$backup_schedule_hours    = [3, 9, 15, 21]
$cleanup_schedule_hours   = [4]

$source_dirs = [$jira_home, $jira_install_dir]
$ignore_dirs = ["$jira_home/tmp/*", "$jira_home/caches/*", "$jira_install_dir/temp/*"]

duplicity::backup_job { "jira":
  backup_server            => $backup_server,
  backup_user              => $backup_user,
  backup_transfer_type     => $backup_transfer_type,
  backup_base              => $backup_base,
  source_dirs              => $source_dirs,
  ignore_dirs              => $ignore_dirs,
  full_backup_interval     => '2W',
  last_full_backup_to_keep => '24',
  last_increment_to_keep   => '110',
  backup_schedule_hours    => $backup_schedule_hours,
  cleanup_schedule_hours   => $cleanup_schedule_hours,
  force_create_dir_by_ssh  => true,
}
